@@ -13,6 +13,8 @@ type Finding struct {
 	StartColumn int
 	EndColumn   int
 
+	Line string `json:"-"`
+
 	Match string
 
 	// Secret contains the full content of what is matched in
@@ -42,6 +44,7 @@ type Finding struct {
 
 // Redact removes sensitive information from a finding.
 func (f *Finding) Redact() {
+	f.Line = strings.Replace(f.Line, f.Secret, "REDACTED", -1)
 	f.Match = strings.Replace(f.Match, f.Secret, "REDACTED", -1)
-	f.Secret = "REDACT"
+	f.Secret = "REDACTED"
 }
